"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prompts_1 = require("@clack/prompts");
const core_1 = require("@oclif/core");
const logger_1 = require("../domains/logging/logger");
const checkNode_1 = tslib_1.__importDefault(require("../domains/magento2/functions/checkNode"));
const checkYarn_1 = tslib_1.__importDefault(require("../domains/magento2/functions/checkYarn"));
const docker_1 = require("../domains/magento2/docker");
const functions_1 = require("../domains/magento2/functions");
const installMagento_1 = require("../domains/magento2/installMagento");
const terminalHelpers_1 = require("../domains/magento2/functions/terminalHelpers");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const i18next_1 = require("i18next");
class M2Only extends core_1.Command {
    async run() {
        const { writeLog, deleteLog } = (0, logger_1.initLogger)();
        (0, prompts_1.intro)('Welcome to the Magento 2 local instance installer!');
        await (0, checkNode_1.default)(writeLog);
        await (0, checkYarn_1.default)(writeLog);
        await (0, docker_1.checkDocker)(writeLog);
        const { magentoDirName, magentoAccessKey, magentoSecretKey } = await (0, functions_1.getMagentoDetails)();
        const magentoDomain = await (0, docker_1.getMagentoDomainName)((0, i18next_1.t)('command.generate_store.magento.domain'));
        await (0, installMagento_1.installMagento)({
            isInstallMagento: true,
            magentoDirName,
            magentoDomain,
            magentoAccessKey,
            magentoSecretKey,
            writeLog
        });
        deleteLog();
        (0, terminalHelpers_1.simpleLog)('Magento 2 local instance installed!');
        (0, terminalHelpers_1.simpleLog)('');
        (0, terminalHelpers_1.simpleLog)('Happy coding! 🎉', picocolors_1.default.green);
        this.exit(0);
    }
}
exports.default = M2Only;
M2Only.description = 'Install local Magento 2 instance';
M2Only.examples = ['<%= config.bin %> <%= command.id %>'];
M2Only.flags = {};
M2Only.args = [];
//# sourceMappingURL=m2-only.js.map