"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fetchIntegrations_1 = tslib_1.__importDefault(require("./fetchIntegrations"));
const git_repository_url_1 = require("../git-repository-url");
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("../magento2/functions/terminalHelpers");
const i18next_1 = require("i18next");
const getIntegration = async (options) => {
    const { message, customIntegrationRepositoryMessage } = options;
    const integrations = await (0, fetchIntegrations_1.default)();
    const customIntegration = {
        name: 'Custom integration',
        gitRepositoryURL: null
    };
    const choices = [...integrations, customIntegration].map((integration) => ({
        name: integration.name,
        value: integration.name
    }));
    const answer = await (0, prompts_1.select)({
        options: choices,
        message
    });
    if ((0, prompts_1.isCancel)(answer)) {
        (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
        process.exit(0);
    }
    if (answer !== customIntegration.name) {
        const selectedIntegration = integrations.find((integration) => integration.name === answer);
        if (!selectedIntegration) {
            throw new Error('Integration not found');
        }
        return selectedIntegration;
    }
    return {
        name: customIntegration.name,
        gitRepositoryURL: await (0, git_repository_url_1.getGitRepositoryURL)(customIntegrationRepositoryMessage)
    };
};
exports.default = getIntegration;
//# sourceMappingURL=getIntegration.js.map