"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const terminalHelpers_1 = require("../functions/terminalHelpers");
const i18next_1 = require("i18next");
/** Checking if Docker is installed and running on user's machine */
const checkDocker = async (writeLog) => {
    const docker = process.platform === 'darwin'
        ? (0, child_process_1.spawn)('docker', ['info'])
        : (0, child_process_1.spawn)('sudo', ['docker', 'info']);
    docker.stderr.on('data', (data) => {
        writeLog(data.toString());
        (0, terminalHelpers_1.simpleLog)(data.toString());
    });
    const isDockerInstalled = await new Promise((resolve) => {
        docker.on('close', (code) => resolve(code === 0));
    });
    if (!isDockerInstalled) {
        writeLog('Docker is not installed or not running. Please make sure that prerequisites are complied with and run command again.');
        (0, terminalHelpers_1.logSimpleErrorMessage)('Docker is not installed or not running. Please make sure that prerequisites are complied with and run command again.');
        (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.magento.failed_log'));
        process.exit(1);
    }
    else {
        writeLog('🐳 Docker is installed and running.');
        (0, terminalHelpers_1.logSimpleInfoMessage)('🐳 Docker is installed and running.');
    }
};
exports.default = checkDocker;
//# sourceMappingURL=checkDocker.js.map