"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const terminalHelpers_1 = require("./terminalHelpers");
const i18next_1 = require("i18next");
const checkYarnVersion = (yarnString) => {
    const yarnVersion = yarnString.split('.')[0];
    if (Number(yarnVersion) === 1 || Number(yarnVersion) === 2) {
        return true;
    }
    return false;
};
/** Checking if Yarn is installed */
const checkYarn = async (writeLog) => {
    const yarn = process.platform === 'win32'
        ? (0, child_process_1.spawn)('yarn.cmd', ['--version'])
        : (0, child_process_1.spawn)('yarn', ['--version']);
    yarn.stdout.on('data', (data) => {
        if (!checkYarnVersion(data.toString())) {
            writeLog((0, i18next_1.t)('command.generate_store.magento.yarn_not_ok'));
            (0, terminalHelpers_1.logSimpleErrorMessage)((0, i18next_1.t)('command.generate_store.magento.yarn_not_ok'));
            (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.magento.failed_log'));
            process.exit(1);
        }
    });
    yarn.stderr.on('data', (data) => {
        writeLog(data.toString());
        (0, terminalHelpers_1.simpleLog)(data.toString());
    });
    const isYarnVersionCorrect = await new Promise((resolve) => {
        yarn.on('close', (code) => resolve(code === 0));
    });
    if (!isYarnVersionCorrect) {
        writeLog((0, i18next_1.t)('command.generate_store.magento.yarn_not_ok'));
        (0, terminalHelpers_1.logSimpleErrorMessage)((0, i18next_1.t)('command.generate_store.magento.yarn_not_ok'));
        (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.magento.failed_log'));
        process.exit(1);
    }
};
exports.default = checkYarn;
//# sourceMappingURL=checkYarn.js.map