"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.installMagento = void 0;
const docker_1 = require("./docker");
const functions_1 = require("./functions");
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("./functions/terminalHelpers");
const i18next_1 = require("i18next");
/** Function responsible for all Magento 2 installation process */
const installMagento = async ({ magentoDirName, magentoDomain, magentoAccessKey, magentoSecretKey, writeLog }) => {
    await (0, docker_1.installMagentoImage)(magentoDirName, magentoDomain, writeLog);
    await (0, functions_1.copyAuth)(magentoDirName, magentoAccessKey, magentoSecretKey);
    await (0, functions_1.handleGraphQL)(magentoDirName, writeLog);
    const isGenerateData = await (0, functions_1.isGenerateSampleData)((0, i18next_1.t)('command.generate_store.magento.sample_data'));
    if (isGenerateData) {
        await (0, functions_1.handleSampleData)(magentoDirName, writeLog);
    }
    else {
        (0, prompts_1.note)((0, i18next_1.t)('command.generate_store.magento.sample_data_note'));
    }
    (0, terminalHelpers_1.logSimpleSuccessMessage)((0, i18next_1.t)('command.generate_store.magento.success'));
};
exports.installMagento = installMagento;
//# sourceMappingURL=installMagento.js.map