"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const terminalHelpers_1 = require("../functions/terminalHelpers");
const prompts_1 = require("@clack/prompts");
const i18next_1 = require("i18next");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
/** Prompts user if they want to overwrite the directory */
const confirmOverwrite = async ({ message, magentoDirName }) => {
    let newMagentoDirName = '';
    const overwrite = await (0, prompts_1.confirm)({
        message
    });
    if ((0, prompts_1.isCancel)(overwrite)) {
        (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
        process.exit(0);
    }
    const sp = (0, prompts_1.spinner)();
    if (overwrite) {
        sp.start(picocolors_1.default.cyan((0, i18next_1.t)('command.generate_store.progress.delete_start')));
        await fs_1.default.rmdirSync(magentoDirName, { recursive: true });
        await fs_1.default.mkdirSync(magentoDirName);
        sp.stop(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.progress.delete_end')));
        newMagentoDirName = magentoDirName;
    }
    if (!overwrite) {
        (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.progress.create_dir'));
        newMagentoDirName = magentoDirName + new Date().getTime().toString();
        fs_1.default.mkdirSync(newMagentoDirName);
    }
    return newMagentoDirName;
};
exports.default = confirmOverwrite;
//# sourceMappingURL=confirmOverwrite.js.map